@@ -23,6 +23,7 @@
 
 #include <config.h>
 #include <glib/gstdio.h>
+#include <glib/glist.h>
 #include <gnome.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-application-registry.h>
@@ -45,7 +46,6 @@ GList *girl_programs;
 GList *girl_stations;
 GList *girl_streams;
 
-
 GtkWidget *girl_app;
 GtkWidget *archivers_selector = NULL;
 GtkWidget *listeners_selector = NULL;
@@ -54,6 +54,8 @@ GtkWidget *stations_selector = NULL;
 GtkWidget *streams_selector = NULL;
 GtkWidget *search_selector = NULL;
 
+gchar *list_item_data_key ="list_item_data";
+
 int main(int argc, char *argv[])
 {
 	gchar *iconname;
@@ -85,7 +87,7 @@ int main(int argc, char *argv[])
 	/* Set up the channels list */
 	stations_selector = create_stations_selector(girl->selected_station_uri,
 						     "girl.xml");
-	
+
 	/* /\* Set up the stations list *\/ */
 	/* stations_selector = create_stations_selector(girl->selected_station_uri, */
 	/* 					     "girl.xml"); */
@@ -96,7 +98,7 @@ int main(int argc, char *argv[])
 
 	g_object_add_weak_pointer(G_OBJECT(stations_selector),
 				  (void **) &(stations_selector));
-	
+
 	/* g_object_add_weak_pointer(G_OBJECT(stations_selector), */
 	/* 			  (void **) &(stations_selector)); */
 
@@ -116,6 +118,14 @@ int main(int argc, char *argv[])
 	if (girl->icon != NULL)
 		gtk_window_set_icon(GTK_WINDOW(girl_app), girl->icon);
 
+#if HAVE_GIRL_RECORD == 1
+	appbar_send_msg(_("%i stations and %i streams found "),
+			girl->station_count, girl->stream_count);
+#else
+	appbar_send_msg(_("%i stations and %i streams found"),
+			girl->station_count, girl->stream_count);
+#endif
+
 	gtk_main();
 	return 0;
 }
@@ -416,6 +426,8 @@ void on_stations_selector_button_clicked(GtkWidget * a, gpointer user_data)
 
 void on_stations_selector_changed(GtkWidget * a, gpointer user_data)
 {
+	GirlStationInfo *station;
+
 	if (girl->selected_station_uri != NULL)
 		g_free(girl->selected_station_uri);
 
@@ -449,6 +461,8 @@ void on_stations_selector_changed(GtkWidget * a, gpointer user_data)
 			girl->selected_station_uri,
 			girl->selected_station_band);
 
+	station->name = g_strdup(g_object_get_data(G_OBJECT(a), "station_name"));
+	/* girl_history = g_list_add(GLIST(girl_history), (GirlStationInfo *)station); */
 	girl_helper_run(girl->selected_station_uri,
 			girl->selected_station_name,
 			GIRL_STREAM_SHOUTCAST,
@@ -636,6 +650,7 @@ void about_app(GtkWidget * a, gpointer user_data)
 					"Andy Daniel Cruz Campos <god_of_war_2@hotmail.com> (Spanish translation)\n"
 					"Mирослав Николић <miroslavnikolic@rocketmail.com> (Serbian translation)\n"
 					"Balázs Meskó <meskobalazs@gmail.com> (Hungarian translation)\n"
+					"Laudivan Freire de Almeida <laudivan@riseup.net> (Brazilian Portuguese translation)\n"
 					      ));
 	gchar* artists[] = { "Wiki Graphic Designer",
 			     "Aly Raj",
@@ -808,6 +823,7 @@ void about_streams(GtkWidget * a, gpointer user_data)
 
 }
 
+
 void on_search_button_clicked(GtkWidget *a, gpointer user_data)
 {
 	GtkWidget *search;
@@ -820,12 +836,12 @@ void on_search_button_clicked(GtkWidget *a, gpointer user_data)
 
 void on_listen_button_clicked(GtkWidget *a, gpointer user_data)
 {
+
 	appbar_send_msg(_("Listening to the radio station %s in %s: %s "),
 			girl->selected_station_name,
 			girl->selected_station_location,
 			girl->selected_station_uri,
 			girl->selected_station_band);
-
 	girl_helper_run(girl->selected_station_uri,
 			girl->selected_station_name,
 			GIRL_STREAM_SHOUTCAST,
